==> jc-1.4.0.tar.gz: org/dellroad/jc/cgen/escape/StackAllocTag.h <==
// public class org.dellroad.jc.cgen.escape.StackAllocTag

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b6292ff05cd23f5d org_dellroad_jc_cgen_escape_StackAllocTag

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_cgen_escape_StackAllocTag_H_
#define _JC_org_dellroad_jc_cgen_escape_StackAllocTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$sub_refs	_jc_org_dellroad_jc_cgen_escape_StackAllocTag$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$sub_nonrefs	_jc_org_dellroad_jc_cgen_escape_StackAllocTag$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$refs	_jc_org_dellroad_jc_cgen_escape_StackAllocTag$refs;
typedef struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$nonrefs	_jc_org_dellroad_jc_cgen_escape_StackAllocTag$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$object	_jc_org_dellroad_jc_cgen_escape_StackAllocTag$object;

typedef struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$fields_struct	_jc_org_dellroad_jc_cgen_escape_StackAllocTag$fields_struct;
typedef const struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$vmethods	_jc_org_dellroad_jc_cgen_escape_StackAllocTag$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$vtable	_jc_org_dellroad_jc_cgen_escape_StackAllocTag$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$vtype	_jc_org_dellroad_jc_cgen_escape_StackAllocTag$vtype;

// Class fields structure
struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$fields_struct {
	struct _jc_java_lang_String$object	*NAME;
};
extern _jc_org_dellroad_jc_cgen_escape_StackAllocTag$fields_struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$class_fields;

// Constructors
extern void _jc_org_dellroad_jc_cgen_escape_StackAllocTag$method$_init$7f1776288300b98d(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$object *, jint);

// Virtual methods
extern jint _jc_org_dellroad_jc_cgen_escape_StackAllocTag$method$getId$d8363e0f5dfda08c(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$object *);
extern struct _jc_java_lang_String$object *_jc_org_dellroad_jc_cgen_escape_StackAllocTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$object *);
extern _jc_byte_array *_jc_org_dellroad_jc_cgen_escape_StackAllocTag$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$object *);
extern struct _jc_java_lang_String$object *_jc_org_dellroad_jc_cgen_escape_StackAllocTag$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$object *);

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_escape_StackAllocTag$method_info$getId$d8363e0f5dfda08c;
extern _jc_method _jc_org_dellroad_jc_cgen_escape_StackAllocTag$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_org_dellroad_jc_cgen_escape_StackAllocTag$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_org_dellroad_jc_cgen_escape_StackAllocTag$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$vmethods {
	jint	(*getId$d8363e0f5dfda08c)(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$object *);
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$object *);
};

// Vtable
struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_cgen_escape_StackAllocTag$vmethods	org_dellroad_jc_cgen_escape_StackAllocTag;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_escape_StackAllocTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$refs {
    _jc_org_dellroad_jc_cgen_escape_StackAllocTag$sub_refs	org_dellroad_jc_cgen_escape_StackAllocTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$sub_nonrefs {
	jint	id;
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_cgen_escape_StackAllocTag$sub_nonrefs	org_dellroad_jc_cgen_escape_StackAllocTag;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$object {
	_jc_org_dellroad_jc_cgen_escape_StackAllocTag$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_escape_StackAllocTag$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_escape_StackAllocTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_escape_StackAllocTag$vtype _jc_org_dellroad_jc_cgen_escape_StackAllocTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_escape_StackAllocTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_escape_StackAllocTag$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_escape_StackAllocTag_H_ */

==> jc-1.4.6.tar.gz: org/dellroad/jc/cgen/escape/StackAllocTag.h <==
// public class org.dellroad.jc.cgen.escape.StackAllocTag

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b6292ff05cd23f5d org_dellroad_jc_cgen_escape_StackAllocTag

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_cgen_escape_StackAllocTag_H_
#define _JC_org_dellroad_jc_cgen_escape_StackAllocTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$sub_refs	_jc_org_dellroad_jc_cgen_escape_StackAllocTag$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$sub_nonrefs	_jc_org_dellroad_jc_cgen_escape_StackAllocTag$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$refs	_jc_org_dellroad_jc_cgen_escape_StackAllocTag$refs;
typedef struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$nonrefs	_jc_org_dellroad_jc_cgen_escape_StackAllocTag$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$object	_jc_org_dellroad_jc_cgen_escape_StackAllocTag$object;

typedef struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$fields_struct	_jc_org_dellroad_jc_cgen_escape_StackAllocTag$fields_struct;
typedef const struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$vmethods	_jc_org_dellroad_jc_cgen_escape_StackAllocTag$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$vtable	_jc_org_dellroad_jc_cgen_escape_StackAllocTag$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$vtype	_jc_org_dellroad_jc_cgen_escape_StackAllocTag$vtype;

// Class fields structure
struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$fields_struct {
	struct _jc_java_lang_String$object	*NAME;
};
extern _jc_org_dellroad_jc_cgen_escape_StackAllocTag$fields_struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$class_fields;

// Constructors
extern void _jc_org_dellroad_jc_cgen_escape_StackAllocTag$method$_init$7f1776288300b98d(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_org_dellroad_jc_cgen_escape_StackAllocTag$method$getId$d8363e0f5dfda08c(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_org_dellroad_jc_cgen_escape_StackAllocTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_org_dellroad_jc_cgen_escape_StackAllocTag$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_org_dellroad_jc_cgen_escape_StackAllocTag$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_escape_StackAllocTag$method_info$getId$d8363e0f5dfda08c;
extern _jc_method _jc_org_dellroad_jc_cgen_escape_StackAllocTag$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_org_dellroad_jc_cgen_escape_StackAllocTag$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_org_dellroad_jc_cgen_escape_StackAllocTag$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$vmethods {
	jint	(*getId$d8363e0f5dfda08c)(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_cgen_escape_StackAllocTag$vmethods	org_dellroad_jc_cgen_escape_StackAllocTag;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_escape_StackAllocTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$refs {
    _jc_org_dellroad_jc_cgen_escape_StackAllocTag$sub_refs	org_dellroad_jc_cgen_escape_StackAllocTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$sub_nonrefs {
	jint	id;
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_cgen_escape_StackAllocTag$sub_nonrefs	org_dellroad_jc_cgen_escape_StackAllocTag;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_escape_StackAllocTag$object {
	_jc_org_dellroad_jc_cgen_escape_StackAllocTag$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_escape_StackAllocTag$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_escape_StackAllocTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_escape_StackAllocTag$vtype _jc_org_dellroad_jc_cgen_escape_StackAllocTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_escape_StackAllocTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_escape_StackAllocTag$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_escape_StackAllocTag_H_ */
